@@ -29,7 +29,7 @@ class NEAL3Way(object):
     ::
     
         bases = {"units": ["animal", "mammal", "bird", "canary"],
-                 "relations": [ ["canary", "bird"], ["bird", "animal"], ["mammal", "animal"] ]}
+                 "is-a": [ ["canary", "bird"], ["bird", "animal"], ["mammal", "animal"] ]}
         associate = {"properties": ["food", "fur", "flying", "yellow"], # properties to be associated between base units and its relations
                      "relations": ["eats", "likes", "travels", "has", "colored"], # relations associated with properties and base units
                      "connections": [ ["animal", "eats", "food"], ["mammal", "has", "fur"], # specific combos of base-props-relations
@@ -37,7 +37,14 @@ class NEAL3Way(object):
     
     **Note:**
     
-    * Specifically the instance of :ref:`InheritanceReaderClass` is the base data for :ref:`NEAL3Way`. An example base data is
+    * One may think of the arguments, ``bases`` and ``associate`` as some a priori knowledge of the embodied agent.
+    * The value for "is-a" must have **at least one** non-empty list.
+    * The result of above restriction is that ``bases`` must have at least two units, i.e. list of the value for "units" have at least two elements.
+    * Usually, the number of "properties" equal the number of base units.
+    * The number of "relations" can be of any number as long as there is at least one.
+    * Finally, the components within "connections" is of the form ``[<base-unit>, <a-relation>, <a-property>]``.
+    * Looking from the context of a sentence one may view ``bases`` as the subject, "properties" (key of ``associate``) as the object and "relations" (also key of ``associate``) as the predicate, and "connections" as the sentence structure.
+    * Specifically the instance of :ref:`InheritanceReaderClass` is the base data for :ref:`NEAL3Way`.
     
     
     Considering the above example whose base data is the instance such that,
@@ -206,7 +213,7 @@ class NEAL3Way(object):
         self.basedata = InheritanceReaderClass()
         self.basedata.numberUnits = len(bases["units"])
         self.basedata.units = bases["units"]
-        self.basedata.isARelationships = bases["relations"]
+        self.basedata.isARelationships = bases["is-a"]
         #self.basedata.getUnitNumber = lambda checkUnit: [ resultUnit for resultUnit in range(0, self.basedata.numberUnits)
         #                                                              if checkUnit==self.basedata.units[resultUnit] ][0]
         #self.propdata = structdata()
@@ -273,6 +280,8 @@ class NEAL3Way(object):
     def __get_overallspikes(self, dataname, neo_data, turnon):
         """Returns `Neo SpikeTrain <https://neo.readthedocs.io/en/stable/api_reference.html#neo.core.SpikeTrain>`_.
         All of it if the data structure is basedata other wise the they are shifted accordingly for propdata and reldata.
+        
+        This function is no longer used by __split_spiketrains but left here for potential/future use.
         """
         if turnon=="all":
             if dataname=="basedata":
@@ -302,8 +311,8 @@ class NEAL3Way(object):
         spkindices = lambda n : (0,ca_size) if (n==0) else ( (n*ca_size), (n*ca_size)+ca_size )
         #
         data = getattr(self, dataname) # "basedata" or "propdata" or "reldata"
-        #overallspikes = neo_data.segments[0].spiketrains
-        overallspikes = self.__get_overallspikes(dataname, neo_data, turnon)
+        overallspikes = neo_data.segments[0].spiketrains
+        #overallspikes = self.__get_overallspikes(dataname, neo_data, turnon) # technically w/o this spike train is not split
         #
         parsed_spiketrains = {"all": overallspikes} # this will be the returned value
         for unit in data.units:
@@ -331,7 +340,7 @@ class NEAL3Way(object):
         legpatches = []
         data = getattr(self, dataname) # "basedata" or "propdata" or "reldata"
         #clrs = self.__generate_compatible_subplot_colors(colorname, data.numberUnits)
-        clrs = cm.get_cmap(colorname, 12) # "Reds", "Greens", "Blues"
+        clrs = cm.get_cmap(colorname, 12) # "Reds", "Blues", "Greens"
         for unit in data.units:
             i = data.getUnitNumber(unit)
             #if self.test_metadata[0]=="all":
@@ -346,14 +355,22 @@ class NEAL3Way(object):
         
     # Private function for returning color map (a tuple) or list of colors
     def __generate_compatible_subplot_colors(self, colorname, numberUnits):
-        """This is no longer used."""
+        """This is no longer used but left here for potential/future use."""
         if self.test_metadata[0]=="all": # returns a tuple
             return cm.get_cmap(colorname, 12) # "Reds", "Greens", "Blues"
         else:
             return ['C{}'.format(i) for i in range(numberUnits)]
     
-    def plot_all(self):
-        """Plot of three subplots such that each subplot (invoking :py:meth:`.__subplot_all`) is the matplotlib's `eventplot <https://matplotlib.org/3.1.1/api/_as_gen/matplotlib.pyplot.eventplot.html>`_
+    def plot_all(self, form="1"):
+        """Plotting spike trains from all the units within every cell assembly can be done in two ways.
+        
+        **Default**
+        
+        Plots all the spike trains in one plot.
+        
+        **``form = "2"``**
+        
+        Plot of three subplots such that each subplot (invoking :py:meth:`.__subplot_all`) is the matplotlib's `eventplot <https://matplotlib.org/3.1.1/api/_as_gen/matplotlib.pyplot.eventplot.html>`_
         of `SpikeTrain <https://neo.readthedocs.io/en/stable/api_reference.html#neo.core.SpikeTrain>`_ such that
         
         +---------+------------------------------------------------------------+----------------------------------+
@@ -361,34 +378,53 @@ class NEAL3Way(object):
         +=========+============================================================+==================================+
         | top     | subject (a.k.a base in ``basedata``)                       | Reds                             |
         +---------+------------------------------------------------------------+----------------------------------+
-        | middle  | predicate (a.k.a relation in ``reldata``)                  | Greens                           |
+        | middle  | object (a.k.a property in ``propdata``)                    | Blues                            |
         +---------+------------------------------------------------------------+----------------------------------+
-        | bottom  | object (a.k.a property in ``propdata``)                    | Blues                            |
+        | bottom  | predicate (a.k.a relation in ``reldata``)                  | Greens                           |
         +---------+------------------------------------------------------------+----------------------------------+
         
         """
-        fig, ((sp1),
-              (sp2),
-              (sp3)) = plt.subplots(3,1, sharex=True)
-        # If turnon is "all" Red color for subject, i.e. base Therefore its spectrum is used here
-        self.__subplot_all("basedata", "Reds", sp1)
-        #
-        # If turnon is "all" Green color for predicate, i.e. relation
-        self.__subplot_all("reldata", "Greens", sp2)
-        #
-        # If turnon is "all" Blue color for object, i.e. property
-        self.__subplot_all("propdata", "Blues", sp3)
-        #
-        sp1.title.set_text("Subject (base)")
-        sp2.title.set_text("Predicate (relation)")
-        sp3.title.set_text("Object (property)")
-        #
-        sp1.set(ylabel="cell units\nper CA")
-        sp2.set(ylabel="cell units\nper CA")
-        sp3.set(ylabel="cell units\nper CA")
-        sp3.set(xlabel="time (ms)")
-        #
-        plt.subplots_adjust( hspace=0.5 ) # spacing for the each subplot title
+        plt.close() # close any previous figure
+        if form=="1":
+            datanames = ["basedata", "propdata", "reldata"]
+            colornames = ["Reds", "Blues", "Greens"]
+            legpatches = []
+            for i in range(len(datanames)):
+                dataname = datanames[i]
+                data = getattr(self, dataname)
+                clrs = cm.get_cmap(colornames[i], 12)
+                for unit in data.units:
+                    j = data.getUnitNumber(unit)
+                    plt.eventplot( self.results[ self.__get_resultskey(dataname) ][ unit ],
+                                   color = clrs(1.0 - (i*0.1) ) )
+                    legpatches.append( mpatches.Patch(color=clrs( 1.0-(i*0.1) ), label=unit) )
+            plt.legend( handles=legpatches, shadow=True, loc='upper right' )
+            plt.ylabel("cell units\nper CA")
+            plt.xlabel("time (ms)")
+            plt.title("Three-way Association")
+        elif form=="2":
+            fig, ((sp1),
+                  (sp2),
+                  (sp3)) = plt.subplots(3,1, sharex=True)
+            # If turnon is "all" Red color for subject, i.e. base Therefore its spectrum is used here
+            self.__subplot_all("basedata", "Reds", sp1)
+            #
+            # If turnon is "all" Blue color for object, i.e. property
+            self.__subplot_all("propdata", "Blues", sp2)
+            #
+            # If turnon is "all" Green color for predicate, i.e. relation
+            self.__subplot_all("reldata", "Greens", sp3)
+            #
+            sp1.title.set_text("Subject (base)")
+            sp2.title.set_text("Object (property)")
+            sp3.title.set_text("Predicate (relation)")
+            #
+            sp1.set(ylabel="cell units\nper CA")
+            sp2.set(ylabel="cell units\nper CA")
+            sp3.set(ylabel="cell units\nper CA")
+            sp3.set(xlabel="time (ms)")
+            #
+            plt.subplots_adjust( hspace=0.5 ) # spacing for the each subplot title
         plt.show()
         
     def plot_specific(self, basename=None, relname=None, propname=None):
@@ -408,17 +444,17 @@ class NEAL3Way(object):
         z_patch = mpatches.Patch( color="red", label=basename )
         sp1.legend( handles=[z_patch], shadow=True )
         #
-        sp2.eventplot( self.results["relation"][relname], color="green" ) # eats
-        z_patch = mpatches.Patch( color="green", label=relname )
+        sp2.eventplot( self.results["property"][propname], color="blue" ) # food
+        z_patch = mpatches.Patch( color="blue", label=propname )
         sp2.legend( handles=[z_patch], shadow=True )
         #
-        sp3.eventplot( self.results["property"][propname], color="blue" ) # food
-        z_patch = mpatches.Patch( color="blue", label=propname )
-        sp3.legend( handles=[z_patch], shadow=True )
+        sp3.eventplot( self.results["relation"][relname], color="green" ) # eats
+        z_patch = mpatches.Patch( color="green", label=relname )
+        sp3.legend( handles=[z_patch], shadow=True, loc='upper left' )
         #
         sp1.title.set_text('Subject (base)')
-        sp2.title.set_text('Predicate (relation)')
-        sp3.title.set_text('Object (property)')
+        sp2.title.set_text('Object (property)')
+        sp3.title.set_text('Predicate (relation)')
         #
         sp1.set(ylabel="cell units\nper CA")
         sp2.set(ylabel="cell units\nper CA")
